@@ -22,7 +22,7 @@ GPIOD_TEST_CASE(version_string, 0, { 1 })
 	gpiod_test_return_if_failed();
 	g_assert_cmpuint(strlen(ver), >, 0);
 
-	regex = g_regex_new("^[0-9]+\\.[0-9]+[0-9a-zA-Z\\.]*$", 0, 0, &err);
+	regex = g_regex_new("^[0-9]+\\.[0-9]+[0-9a-zA-Z\\.-]*$", 0, 0, &err);
 	g_assert_null(err);
 	gpiod_test_return_if_failed();
 	g_assert_true(g_regex_match(regex, ver, 0, NULL));
